@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use base qw( Alien::Base );
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub fpm_gem_home {
     my ($class) = @_;
@@ -17,18 +17,18 @@ __END__
 
 =head1 NAME
 
-Alien::fpm = Find or install fpm
+Alien::fpm - Find or install fpm
 
 =head1 SYNOPSIS
 
-use Alien::fpm;
+ use Alien::fpm;
 
-use Env qw( @PATH @GEM_PATH );
+ use Env qw( @PATH @GEM_PATH );
 
-unshift @PATH, Alien::fpm->bin_dir;
-unshift @GEM_PATH, Alien::fpm->fpm_gem_home;
+ unshift @PATH, Alien::fpm->bin_dir;
+ unshift @GEM_PATH, Alien::fpm->fpm_gem_home;
 
-system('fpm --verbose -s cpan -t rpm Fennec');
+ system('fpm --verbose -s cpan -t rpm Fennec');
 
 =head1 DESCRIPTION
 
